@@ -60,7 +60,7 @@ get_dataset <- function(
     u <- paste0(api_url(server), "datasets/", dataset)
   }
   r <- httr::GET(u, httr::add_headers("X-Dataverse-key" = key), ...)
-  httr::stop_for_status(r)
+  httr::stop_for_status(r, task = httr::content(r)$message)
   parse_dataset(httr::content(r, as = "text", encoding = "UTF-8"))
 }
 
@@ -84,7 +84,7 @@ dataset_metadata <- function(
   }
 
   r <- httr::GET(u, httr::add_headers("X-Dataverse-key" = key), ...)
-  httr::stop_for_status(r)
+  httr::stop_for_status(r, task = httr::content(r)$message)
   out <- httr::content(r, as = "text", encoding = "UTF-8")
   jsonlite::fromJSON(out)[["data"]]
 }
@@ -101,7 +101,7 @@ dataset_files <- function(
   dataset <- dataset_id(dataset, key = key, server = server, ...)
   u <- paste0(api_url(server), "datasets/", dataset, "/versions/", version, "/files")
   r <- httr::GET(u, httr::add_headers("X-Dataverse-key" = key), ...)
-  httr::stop_for_status(r)
+  httr::stop_for_status(r, task = httr::content(r)$message)
   out <- jsonlite::fromJSON(httr::content(r, as = "text", encoding = "UTF-8"), simplifyDataFrame = FALSE)$data
   structure(lapply(out, `class<-`, "dataverse_file"))
 }
