@@ -2,9 +2,11 @@
 # https://doi.org/10.70122/FK2/HXJVJU
 
 test_that("download tab from DOI and filename", {
+  testthat::skip_if_offline("demo.dataverse.org")
   dv        <- get_dataverse("dataverse-client-r")
   contents  <- dataverse_contents(dv)
-  actual    <- dataset_files(contents[[1]])
+  ds_index  <- which(sapply(contents, function(x) x$identifier) == "FK2/HXJVJU")
+  actual    <- dataset_files(contents[[ds_index]])
   yml       <- yaml::read_yaml(system.file("dataset-basketball/expected-metadata.yml", package = "dataverse"))
 
   ds_expected <-
